# Начало

Первым делом мы должны установить нашу библиотеку.
```pip install EasyDonate-Py```


# Получение информации о магазине

Получение информации о **магазине** осуществляется через функцию ```shop_info(shop_key="<ВАШ СЕКРЕТНЫЙ КЛЮЧ МАГАЗИНА>")```

### Все функции
```
shop_info(shop_key="<ВАШ СЕКРЕТНЫЙ КЛЮЧ МАГАЗИНА>")
```
флизан доделает